.. _virtualenv: http://www.virtualenv.org/
.. _Optimus: https://github.com/sveetch/Optimus

This is the default Readme file for your `Optimus`_ project.

Read the Optimus documentation on `<https://optimus.readthedocs.org/>`_

Install
=======

It is recommanded to install it in a `virtualenv`_ environment then install the project dependancies.

Project dependancies are usually in a ``requirements.txt`` file to use with ``pip``.

Example : ::

    virtualenv --no-site-packages my_project
    cd my_project
    source bin/activate
    pip install -r requirements.txt
